@@ -81,6 +81,8 @@ class ChangesProcessor(object):
                 csv_file = open(csv_path, 'rb')
                 reader = csv.DictReader(csv_file, quotechar=b"'")
                 for row in reader:
+                    log.debug("calling func {0} with row: {1}".format(
+                            repr(func.__name__), repr(row)))
                     func(row, session)
                     session.flush()
                 csv_file.close()
