@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,34 +25,30 @@
 Mail Utilities
 """
 
-import os.path
+from __future__ import unicode_literals
+
+import os
 import socket
 
-from mako.template import Template
-
-from rattail.files import resource_path, creation_time
-from rattail.mail import sendmail_with_config
+from rattail.filemon import Action
+from rattail.files import creation_time
+from rattail.mail import send_email
 
 
-def email_import_error(path, template_path=None):
+class EmailImportError(Action):
     """
     Send an email informing someone of an SMS import error.
 
-    This function is designed for use with the file monitor, which would
-    presumably be watching a SMS node's "ZE" (import error) folder.
+    This is meant to be used with the file monitor, which would presumably be
+    watching an SMS node's "ZE" (import error) folder.
     """
-    if template_path is None:
-        template_path = 'rattail_locsms:data/templates/email_import_error.mako'
-    template_path = resource_path(template_path)
 
-    path = os.path.abspath(path)
-    data = {
-        'hostname': socket.gethostname(),
-        'abspath': path,
-        'dirname': os.path.dirname(path),
-        'basename': os.path.basename(path),
-        'created': creation_time(path),
-        }
-
-    template = Template(filename=template_path)
-    sendmail_with_config('locsms_import_error', template.render(**data), content_type='text/html')
+    def __call__(self, path, *args, **kwargs):
+        data = {
+            'hostname':         socket.gethostname(),
+            'abspath':          path,
+            'dirname':          os.path.dirname(path),
+            'basename':         os.path.basename(path),
+            'created':          creation_time(path),
+            }
+        send_email(self.config, 'locsms_import_error', data)
